@@ -238,7 +238,6 @@ class Database:
                     year_month_involved_list.append(year_month)
 
             year_month_involved_list.append((datetime.datetime.strptime(year_month_involved_list[-1], '%y%m') + relativedelta(months=1)).strftime('%y%m'))
-
             year_month_involved_list_str = json.dumps(str(year_month_involved_list))
 
             year_month_involved_list_str = year_month_involved_list_str.replace('[', '')
@@ -331,11 +330,15 @@ class Database:
                         df = df.reset_index(drop=True)
                         date_time_list = df['datetime'].to_list()
 
+                        df = df.sort_values(by='datetime')
+
                         if '1D' not in freq:
                             if len(date_time_list_list) > 0:
                                 date_time_intersect = (set(date_time_list_list).intersection(date_time_list))
                                 if len(date_time_intersect) == 0:
                                     df_list.append(df)
+                            else:
+                                df_list.append(df)
                         else:
                             date_time_intersect = (set(date_time_list_list).intersection(date_time_list))
                             date_time_intersect = list(date_time_intersect)
@@ -351,7 +354,6 @@ class Database:
                     cols = ['datetime', 'date', 'open', 'high', 'low', 'close', 'volume', 'expiry_date']
                 df = pd.concat(df_list)
 
-
                 if '1D' not in freq:
                     df['datetime'] = pd.to_datetime(df['datetime'], format='%Y%m%d %H%M%S')
                     df['RTH'] = df['RTH'].astype(bool)
@@ -383,6 +385,8 @@ class Database:
                 if '1D' not in freq and rth_only == True:
                     df = df[df['RTH'] == True]
 
+                #df = df.drop_duplicates(keep='last')
+
                 return df
     
         else:
@@ -877,7 +881,7 @@ class Database:
 
                 df['date'] = pd.to_datetime(df['date'], format='%Y%m%d')
 
-                df = df[['date', 'percent', 'code', 'share']]
+                df = df[['date', 'code', 'percent', 'share']]
                 df = df.set_index(keys='date')
                 df = df.sort_index()
 
@@ -1288,7 +1292,11 @@ class Database:
             response_ok = response_check(response)
             if response_ok == True:
 
-                result = json.loads(json.loads(response.content).replace("'", "\""))
+                json_content = json.loads(response.content)
+                if 'nan' in json_content:
+                    result = json.loads(json_content.replace("'", "\"").replace("nan", "0"))
+                else:
+                    result = json.loads(json_content.replace("'", "\""))
 
                 df_list = []
                 for item in result:
